@@ -149,6 +149,32 @@ class Client(Callbacks, SocketHandler):
         self.active = True
         threading.Thread(target=self.run_vc, args=[comId, chatId, joinType])
 
+    def start_video_call(self, comId: str, chatId: str, joinType: int = 1):
+        data = {
+            "o": {
+                "ndcId": comId,
+                "threadId": chatId,
+                "joinRole": joinType,
+                "id": "2154531"
+            },
+            "t": 112
+        }
+        data = json.dumps(data)
+        self.send(data)
+        data = {
+            "o": {
+                "ndcId": comId,
+                "threadId": chatId,
+                "channelType": 4,
+                "id": "2154531"
+            },
+            "t": 108
+        }
+        data = json.dumps(data)
+        self.send(data)
+        self.active = True
+        threading.Thread(target=self.run_vc, args=[comId, chatId, joinType])
+
     def end_vc(self, comId: str, chatId: str, joinType: int = 2):
         self.active = False
         data = {
@@ -163,6 +189,37 @@ class Client(Callbacks, SocketHandler):
         data = json.dumps(data)
         self.send(data)
 
+    def send_action(self, actions: list,comId:str ,chatId: str =None, blogId: str = None, quizId: str = None, lastAction: bool = False):
+        # Action List
+        # Browsing
+
+        if lastAction is True: t = 306
+        else: t = 304
+
+        data = {
+            "o": {
+                "actions": actions,
+                "target": f"ndc://x{comId}/",
+                "ndcId": int(comId),
+                "params": {"topicIds": [45841, 17254, 26542, 42031, 22542, 16371, 6059, 41542, 15852]},
+                "id": "273887"
+            },
+            "t": t
+        }
+        
+
+        if blogId is not None or quizId is not None:
+            data["o"]["target"] = f"ndc://x{comId}/blog/{blogId}"
+            if blogId is not None: data["o"]["params"]["blogType"] = 0
+            if quizId is not None: data["o"]["params"]["blogType"] = 6
+        if chatId is not None:
+            data["o"]["target"]=f"ndc://x{comId}/chat-thread/{chatId}"
+            data["o"]["params"]={"membershipStatus":1,"threadType":2}
+
+        #print(data)
+        sleep(2)
+        return self.send(json.dumps(data))
+
     def login_sid(self, SID: str):
         """
         Login into an account with an SID
