@@ -1,13 +1,14 @@
 from amino.lib.util import device
-import requests
-def sigg(data):
-    da={"data":data}
-    try:
-        r=requests.post(f'https://sigg123.herokuapp.com/sig-gen',data=da)
-        return r.json()["sig"]
-    except:
-        sigg(data)
+import hmac
+import base64
+from hashlib import sha1
+from uuid import uuid4
 sid = None
+def sigg(data):
+        key=' fbf98eb3a07a9042ee5593b10ce9f3286a69d4e2'
+        mac = hmac.new(bytes.fromhex(key), data.encode("utf-8"), sha1)
+        digest = bytes.fromhex("32") + mac.digest()
+        return base64.b64encode(digest).decode("utf-8")
 
 class Headers:
     def __init__(self, data = None, type = None, deviceId: str = None, sig: str = None):
@@ -29,9 +30,11 @@ class Headers:
 
         if data:
             headers["Content-Length"] = str(len(data))
-            headers["NDC-MSG-SIG"]=sigg(data)
-            
+            signature=None
+            try: signature=sigg(data)
+            except: pass
+            headers["NDC-MSG-SIG"] = signature
         if sid: headers["NDCAUTH"] = f"sid={sid}"
         if type: headers["Content-Type"] = type
         #if sig: headers["NDC-MSG-SIG"] = sig
-        self.headers = headers
+        self.headers = headers
\ No newline at end of file
